@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -31,14 +29,13 @@ from typing import (
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.pubsublite_v1.types import subscriber
-
 from .transports.base import SubscriberServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import SubscriberServiceGrpcAsyncIOTransport
 from .client import SubscriberServiceClient
@@ -60,35 +57,61 @@ class SubscriberServiceAsyncClient:
     parse_common_billing_account_path = staticmethod(
         SubscriberServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(SubscriberServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         SubscriberServiceClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         SubscriberServiceClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         SubscriberServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(SubscriberServiceClient.common_project_path)
     parse_common_project_path = staticmethod(
         SubscriberServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(SubscriberServiceClient.common_location_path)
     parse_common_location_path = staticmethod(
         SubscriberServiceClient.parse_common_location_path
     )
 
-    from_service_account_file = SubscriberServiceClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            SubscriberServiceAsyncClient: The constructed client.
+        """
+        return SubscriberServiceClient.from_service_account_info.__func__(SubscriberServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            SubscriberServiceAsyncClient: The constructed client.
+        """
+        return SubscriberServiceClient.from_service_account_file.__func__(SubscriberServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> SubscriberServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             SubscriberServiceTransport: The transport used by the client instance.
@@ -102,12 +125,12 @@ class SubscriberServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, SubscriberServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the subscriber service client.
+        """Instantiates the subscriber service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -139,7 +162,6 @@ class SubscriberServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = SubscriberServiceClient(
             credentials=credentials,
             transport=transport,
@@ -159,7 +181,7 @@ class SubscriberServiceAsyncClient:
         messages.
 
         Args:
-            requests (AsyncIterator[`~.subscriber.SubscribeRequest`]):
+            requests (AsyncIterator[`google.cloud.pubsublite_v1.types.SubscribeRequest`]):
                 The request object AsyncIterator. A request sent from the client to
                 the server on a stream.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -169,7 +191,7 @@ class SubscriberServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            AsyncIterable[~.subscriber.SubscribeResponse]:
+            AsyncIterable[google.cloud.pubsublite_v1.types.SubscribeResponse]:
                 Response to SubscribeRequest.
         """
 
